package com.ruoyi.mall.service.impl;

import com.ruoyi.mall.domain.MallConfigLevel;
import com.ruoyi.mall.domain.Vo.SchoolLevelVO;
import com.ruoyi.mall.mapper.MallConfigLevelMapper;
import com.ruoyi.mall.service.IMallConfigLevelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 办学层次设置（985、211）Service业务层处理
 *
 * @author Lsm
 * @date 2023-10-18
 */
@Service
public class MallConfigLevelServiceImpl implements IMallConfigLevelService
{
    @Resource
    private MallConfigLevelMapper mallConfigLevelMapper;

    /**
     * 查询办学层次设置（985、211）
     *
     * @param configLevelId 办学层次设置（985、211）主键
     * @return 办学层次设置（985、211）
     */
    @Override
    public MallConfigLevel selectMallConfigLevelByConfigLevelId(Long configLevelId)
    {
        return mallConfigLevelMapper.selectMallConfigLevelByConfigLevelId(configLevelId);
    }

    /**
     * 查询办学层次设置（985、211）列表
     *
     * @param mallConfigLevel 办学层次设置（985、211）
     * @return 办学层次设置（985、211）
     */
    @Override
    public List<MallConfigLevel> selectMallConfigLevelList(MallConfigLevel mallConfigLevel)
    {
        return mallConfigLevelMapper.selectMallConfigLevelList(mallConfigLevel);
    }

    /**
     * 新增办学层次设置（985、211）
     *
     * @param mallConfigLevel 办学层次设置（985、211）
     * @return 结果
     */
    @Override
    public int insertMallConfigLevel(MallConfigLevel mallConfigLevel)
    {
        return mallConfigLevelMapper.insertMallConfigLevel(mallConfigLevel);
    }

    /**
     * 修改办学层次设置（985、211）
     *
     * @param mallConfigLevel 办学层次设置（985、211）
     * @return 结果
     */
    @Override
    public int updateMallConfigLevel(MallConfigLevel mallConfigLevel)
    {
        return mallConfigLevelMapper.updateMallConfigLevel(mallConfigLevel);
    }

    /**
     * 批量删除办学层次设置（985、211）
     *
     * @param configLevelIds 需要删除的办学层次设置（985、211）主键
     * @return 结果
     */
    @Override
    public int deleteMallConfigLevelByConfigLevelIds(Long[] configLevelIds)
    {
        return mallConfigLevelMapper.deleteMallConfigLevelByConfigLevelIds(configLevelIds);
    }

    /**
     * 删除办学层次设置（985、211）信息
     *
     * @param configLevelId 办学层次设置（985、211）主键
     * @return 结果
     */
    @Override
    public int deleteMallConfigLevelByConfigLevelId(Long configLevelId)
    {
        return mallConfigLevelMapper.deleteMallConfigLevelByConfigLevelId(configLevelId);
    }

    /**
     * 办学层次列表
     * @return 结果
     */
    @Override
    public List<SchoolLevelVO> selectLevelList() {
        return mallConfigLevelMapper.selectLevelList();
    }
}
